summaryrefslogtreecommitdiff
Side-by-side diff
Diffstat (more/less context) (show whitespace changes)
-rw-r--r--core/pim/addressbook/abtable.cpp1
-rw-r--r--core/pim/addressbook/abview.cpp36
-rw-r--r--core/pim/addressbook/addressbook.cpp7
3 files changed, 21 insertions, 23 deletions
diff --git a/core/pim/addressbook/abtable.cpp b/core/pim/addressbook/abtable.cpp
index 0be7d1a..49e66ad 100644
--- a/core/pim/addressbook/abtable.cpp
+++ b/core/pim/addressbook/abtable.cpp
@@ -158,9 +158,8 @@ void AbTable::setContacts( const Opie::OPimContactAccess::List& viewList )
setSorting( false );
setPaintingEnabled( FALSE );
- Opie::OPimContactAccess::List::Iterator it;
setNumRows( m_viewList.count() );
// int row = 0;
// for ( it = m_viewList.begin(); it != m_viewList.end(); ++it )
// insertIntoTable( *it, row++ );
diff --git a/core/pim/addressbook/addressbook.cpp b/core/pim/addressbook/addressbook.cpp
index 6984501..faae0a9 100644
--- a/core/pim/addressbook/addressbook.cpp
+++ b/core/pim/addressbook/addressbook.cpp
@@ -853,10 +853,13 @@ void AddressbookWindow::slotSetCategory( const QString &category )
{
odebug << "void AddressbookWindow::slotSetCategory( " << category << " )" << oendl;
// Tell the view about the selected category
- m_config.setCategory( category );
- m_abView -> setShowByCategory( category );
+ QString cat = category;
+ if ( cat == tr( "All" ) )
+ cat = QString::null;
+ m_config.setCategory( cat );
+ m_abView -> setShowByCategory( cat );
}
void AddressbookWindow::slotViewSwitched( int view )
{
diff --git a/core/pim/addressbook/abview.cpp b/core/pim/addressbook/abview.cpp
index 6be19f8..34035fd 100644
--- a/core/pim/addressbook/abview.cpp
+++ b/core/pim/addressbook/abview.cpp
@@ -41,9 +41,9 @@ AbView::AbView ( QWidget* parent, const QValueList<int>& ordered ):
QWidget(parent),
mCat(0),
m_inSearch( false ),
m_inPersonal( false ),
- m_curr_category( -1 ),
+ m_curr_category( 0 ),
m_curr_View( TableView ),
m_prev_View( TableView ),
m_curr_Contact ( 0 ),
m_contactdb ( 0l ),
@@ -156,21 +156,10 @@ void AbView::load()
// Letter Search is stopped at this place
emit signalClearLetterPicker();
- if ( m_curr_category == 0 ) {
- // Show unfiled
m_list = m_contactdb->sorted( true, Opie::OPimContactAccess::SortFileAsName,
- Opie::OPimContactAccess::DoNotShowWithCategory, 0 );
- } else if ( m_curr_category != -1 ){
- // Just show selected category
- m_list = m_contactdb->sorted( true, Opie::OPimContactAccess::SortFileAsName,
- Opie::OPimBase::FilterCategory, m_curr_category );
- } else {
- // Show all categories
- m_list = m_contactdb->sorted( true, Opie::OPimContactAccess::SortFileAsName,
- Opie::OPimBase::FilterOff, 0 );
- }
+ Opie::OPimContactAccess::FilterCategory, m_curr_category );
// if ( m_curr_category != -1 )
// clearForCategory();
@@ -198,11 +187,13 @@ void AbView::setShowByCategory( const QString& cat )
odebug << "AbView::setShowCategory( const QString& cat )" << oendl;
int intCat = 0;
- // All (cat == NULL) will be stored as -1
- if ( cat.isNull() )
+ // Unfiled will be stored as -1
+ if ( cat == tr( "Unfiled" ) )
intCat = -1;
+ else if ( cat.isNull() )
+ intCat = 0;
else
intCat = mCat.id("Contacts", cat );
// Just do anything if we really change the category
@@ -211,11 +202,11 @@ void AbView::setShowByCategory( const QString& cat )
// << m_curr_category << oendl;
m_curr_category = intCat;
emit signalClearLetterPicker();
-
load();
}
+ m_curr_category = intCat;
}
void AbView::setShowToView( Views view )
@@ -264,10 +255,15 @@ void AbView::setShowByLetter( char c, AbConfig::LPSearchMode mode )
<< "I will ignore it.." << oendl;
return;
}
m_list = m_contactdb->queryByExample( query, Opie::OPimContactAccess::WildCards | Opie::OPimContactAccess::IgnoreCase );
- if ( m_curr_category != -1 )
+
+ if ( m_curr_category != 0 )
clearForCategory();
+
+ // Sort filtered results
+ m_list = m_contactdb->sorted( m_list, true, Opie::OPimContactAccess::SortFileAsName,
+ Opie::OPimContactAccess::FilterCategory, m_curr_category );
m_curr_Contact = 0;
}
updateView( true );
}
@@ -377,9 +373,9 @@ void AbView::slotDoFind( const QString &str, bool caseSensitive, bool useRegExp,
// Now remove all contacts with wrong category (if any selected)
// This algorithm is a litte bit ineffective, but
// we will not have a lot of matching entries..
- if ( m_curr_category != -1 )
+ if ( m_curr_category != 0 )
clearForCategory();
// Now show all found entries
updateView( true );
@@ -417,9 +413,9 @@ void AbView::clearForCategory()
Opie::OPimContactAccess::List::Iterator it;
// Now remove all contacts with wrong category if any category selected
Opie::OPimContactAccess::List allList = m_list;
- if ( m_curr_category != -1 ){
+ if ( m_curr_category != 0 ){
for ( it = allList.begin(); it != allList.end(); ++it ){
if ( !contactCompare( *it, m_curr_category ) ){
//odebug << "Removing " << (*it).uid() << oendl;
m_list.remove( (*it).uid() );
@@ -440,9 +436,9 @@ bool AbView::contactCompare( const Opie::OPimContact &cnt, int category )
// odebug << "Number of categories: " << cats.count() << oendl;
returnMe = false;
- if ( cats.count() == 0 && category == 0 )
+ if ( cats.count() == 0 && category == -1 )
// Contacts with no category will just shown on "All" and "Unfiled"
returnMe = true;
else {
int i;